package App::size_dir_diff;

our $VERSION = 0.3.4;

=head1 NAME

App::size_dir_diff - find differences between two directories 

=head1 DESCRIPTION

This is a stub module, see F<script/size_dir_diff> for details of the script.

=head1 AUTHOR

Jonas Jensen

=head1 LICENSE

gpl_2

=cut

1;
